Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1394)

Unified Diff: runtime/vm/code_generator_ia32.cc

Issue 8503028: Runtime type checking should be skipped for Object as destination type. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 9 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/object.h » ('j') | runtime/vm/object.h » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/code_generator_ia32.cc
===================================================================
--- runtime/vm/code_generator_ia32.cc (revision 1325)
+++ runtime/vm/code_generator_ia32.cc (working copy)
@@ -25,7 +25,7 @@
DEFINE_FLAG(bool, print_scopes, false, "Print scopes of local variables.");
DEFINE_FLAG(bool, trace_functions, false, "Trace entry of each function.");
DEFINE_FLAG(int, optimization_invocation_threshold, 1000,
- "number of invocations before a fucntion is optimized, -1 means never.");
+ "number of invocations before a function is optimized, -1 means never.");
DECLARE_FLAG(bool, enable_type_checks);
DECLARE_FLAG(bool, report_invocation_count);
DECLARE_FLAG(bool, trace_compiler);
@@ -1508,8 +1508,8 @@
ASSERT(!dst_type.IsNull());
ASSERT(dst_type.IsFinalized());
- // Any expression is assignable to the DynamicType. Skip the test.
- if (dst_type.IsDynamicType()) {
+ // Any expression is assignable to the DynamicType or Object. Skip the test.
regis 2011/11/08 21:18:10 Any expression is always assignable to the Dynamic
srdjan 2011/11/08 21:28:47 Done.
+ if (dst_type.IsDynamicType() || dst_type.IsObjectType()) {
return;
}
« no previous file with comments | « no previous file | runtime/vm/object.h » ('j') | runtime/vm/object.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698